@@ -5,7 +5,6 @@ from typing import AsyncIterable, AsyncIterator, List, Optional, Type
 
 from .._exceptions import ConnectionNotAvailable, UnsupportedProtocol
 from .._models import Origin, Request, Response
-from .._ssl import default_ssl_context
 from .._synchronization import AsyncEvent, AsyncLock
 from ..backends.auto import AutoBackend
 from ..backends.base import AsyncNetworkBackend
@@ -82,9 +81,6 @@ class AsyncConnectionPool(AsyncRequestInterface):
             uds: Path to a Unix Domain Socket to use instead of TCP sockets.
             network_backend: A backend instance to use for handling network I/O.
         """
-        if ssl_context is None:
-            ssl_context = default_ssl_context()
-
         self._ssl_context = ssl_context
 
         self._max_connections = (
@@ -243,7 +239,7 @@ class AsyncConnectionPool(AsyncRequestInterface):
                     # status so that the request becomes queued again.
                     status.unset_connection()
                     await self._attempt_to_acquire_connection(status)
-            except Exception as exc:
+            except BaseException as exc:
                 await self.response_closed(status)
                 raise exc
             else:
@@ -271,9 +267,10 @@ class AsyncConnectionPool(AsyncRequestInterface):
 
         async with self._pool_lock:
             # Update the state of the connection pool.
-            self._requests.remove(status)
+            if status in self._requests:
+                self._requests.remove(status)
 
-            if connection.is_closed():
+            if connection.is_closed() and connection in self._pool:
                 self._pool.remove(connection)
 
             # Since we've had a response closed, it's possible we'll now be able
@@ -295,11 +292,19 @@ class AsyncConnectionPool(AsyncRequestInterface):
         Close any connections in the pool.
         """
         async with self._pool_lock:
+            requests_still_in_flight = len(self._requests)
+
             for connection in self._pool:
                 await connection.aclose()
             self._pool = []
             self._requests = []
 
+            if requests_still_in_flight:
+                raise RuntimeError(
+                    f"The connection pool was closed while {requests_still_in_flight} "
+                    f"HTTP requests/responses were still in-flight."
+                )
+
     async def __aenter__(self) -> "AsyncConnectionPool":
         return self
 
